@@ -234,9 +234,12 @@ class DymolaAPI(SimulationAPI):
             self.pool.map(self._setup_dymola_interface, [True for _ in range(self.n_cpu)])
         # For translation etc. always setup a default dymola instance
         self.dymola = self._setup_dymola_interface(use_mp=False)
+
         self.fully_initialized = True
         # Trigger on init.
         self._update_model()
+        # Set result_names to output variables.
+        self.result_names = list(self.outputs.keys())
 
         # Check if some kwargs are still present. If so, inform the user about
         # false usage of kwargs:
